# Secret Server Package

[Secret Server](https://www.thycotic.com/secretserver) is an enterprise-grade Privileged Access Management (PAM) solution available both on-premises or as a cloud-based subscription. Credentials used in your automation processes can be stored and retrieved via Secret Server's REST API to secure your scripts and workflows.

SecretServerPy is a Python package that you use for quickly retrieving credentials from your Secret Server environment, among other things.

## Install

SecretServerPy requires Python 3.7 and above.

MacOs/Linux:

```console
python3 -m pip install secretserverpy
```

Windows:

```console
python -m pip install secretserverpy
```

## Usage

í ½íº§ Under construction í ½íº§

## Build Environment

The package requires Python 3.7 or higher.

Ensuring `python` is in your `PATH`, run:

```powershell
git clone https://github.com/thycotic-ps/secretserverpy
cd secretserverpy
```
